﻿/*  ----------------------------------------------------------------------------
 *  WestLaw Business
 *  ----------------------------------------------------------------------------
 *  Copyright 2011 Thomson Reuters Global Resources.  All Rights Reserved.
 *  Proprietary and Confidential information of TRGR.
 *  Disclosure, Use, or Reproduction without the written authorization of TRGR is prohibited.
 *  ----------------------------------------------------------------------------
 *  Author:     TLR\C105578 (Jim Sugrue)
 *  ----------------------------------------------------------------------------
 */

namespace TRGR.WLB.UE.UI
{
    using System.Windows;
    using Microsoft.Practices.Prism.Events;
    using Microsoft.Practices.Prism.Modularity;
    using Microsoft.Practices.Prism.UnityExtensions;
    using Microsoft.Practices.ServiceLocation;
    using Microsoft.Practices.Unity;
    using Modules.Maintenance;
    using Modules.Shell;

    using Test;

    /// <summary>
    /// This class initializes the Unity Container and configures the Prism Module Catalog
    /// </summary>
    public class Bootstrapper : UnityBootstrapper
    {
        /// <summary>
        /// Creates and returns an instance of the application's Shell Window
        /// </summary>
        /// <returns>An instance of the Shell View</returns>
        protected override DependencyObject CreateShell()
        {
            return ServiceLocator.Current.GetInstance<Shell>();
        }

        /// <summary>
        /// Initializes and shows the Shell
        /// </summary>
        protected override void InitializeShell()
        {
            base.InitializeShell();

            // create and show the application's shell window
            Application.Current.MainWindow = (Window)this.Shell;
            Application.Current.MainWindow.WindowState = WindowState.Maximized;
            Application.Current.MainWindow.Show();
        }

        /// <summary>
        /// Configures application specific modules
        /// </summary>
        protected override void ConfigureModuleCatalog()
        {
            base.ConfigureModuleCatalog();

            var moduleCatalog = (ModuleCatalog)this.ModuleCatalog;

            // add application modules to the catalog
            moduleCatalog.AddModule(typeof(ShellModule));
            moduleCatalog.AddModule(typeof(MaintenanceModule));
        }

        /// <summary>
        /// Configures the Unity Container and registers interfaces to concrete types
        /// </summary>
        protected override void ConfigureContainer()
        {
            base.ConfigureContainer();

            // register global types with the container
            Container.RegisterType(typeof(IEventAggregator), typeof(EventAggregator));

            Container.RegisterType(typeof(MaintenanceView), new ContainerControlledLifetimeManager());
        }
    }
}
